@@ -222,6 +222,40 @@ def _check_mcp_auto_configuration():
         logger = get_logger("cli")
         logger.debug(f"MCP auto-configuration check failed: {e}")
 
+    # Skip MCP service fixes for the doctor command
+    # The doctor command performs its own comprehensive MCP service check
+    # Running both would cause duplicate checks and log messages (9 seconds apart)
+    import sys
+
+    if len(sys.argv) > 1 and sys.argv[1] == "doctor":
+        return
+
+    # Also ensure MCP services are properly configured in ~/.claude.json
+    # This fixes incorrect paths and adds missing services
+    try:
+        from ..core.logger import get_logger
+        from ..services.mcp_config_manager import MCPConfigManager
+
+        logger = get_logger("cli")
+        mcp_manager = MCPConfigManager()
+
+        # Fix any corrupted installations first
+        fix_success, fix_message = mcp_manager.fix_mcp_service_issues()
+        if fix_message and "Fixed:" in fix_message:
+            logger.info(f"MCP service fixes applied: {fix_message}")
+
+        # Ensure all services are configured correctly
+        config_success, config_message = mcp_manager.ensure_mcp_services_configured()
+        if config_message and "Added MCP services" in config_message:
+            logger.info(f"MCP services configured: {config_message}")
+
+    except Exception as e:
+        # Non-critical - log but don't fail
+        from ..core.logger import get_logger
+
+        logger = get_logger("cli")
+        logger.debug(f"MCP services configuration update failed: {e}")
+
 
 def _verify_mcp_gateway_startup():
     """
@@ -236,8 +270,8 @@ def _verify_mcp_gateway_startup():
     """
     # Quick verification of MCP services installation
     try:
-        from ..services.mcp_service_verifier import verify_mcp_services_on_startup
         from ..core.logger import get_logger
+        from ..services.mcp_service_verifier import verify_mcp_services_on_startup
 
         logger = get_logger("mcp_verify")
         all_ok, message = verify_mcp_services_on_startup()
@@ -263,23 +297,31 @@ def _verify_mcp_gateway_startup():
         # Quick check first - if already configured, skip detailed verification
         gateway_configured = is_mcp_gateway_configured()
 
-        # Pre-warm MCP servers regardless of gateway config
-        # This eliminates the 11.9s delay on first agent invocation
+        # DISABLED: Pre-warming MCP servers can interfere with Claude Code's MCP management
+        # This was causing issues with MCP server initialization and stderr handling
+        # def run_pre_warming():
+        #     loop = None
+        #     try:
+        #         start_time = time.time()
+        #         loop = asyncio.new_event_loop()
+        #         asyncio.set_event_loop(loop)
+        #
+        #         # Pre-warm MCP servers (especially vector search)
+        #         logger.info("Pre-warming MCP servers to eliminate startup delay...")
+        #         loop.run_until_complete(pre_warm_mcp_servers())
+        #
+        #         pre_warm_time = time.time() - start_time
+        #         if pre_warm_time > 1.0:
+        #             logger.info(f"MCP servers pre-warmed in {pre_warm_time:.2f}s")
+
+        # Dummy function to maintain structure
         def run_pre_warming():
             loop = None
             try:
-                start_time = time.time()
+                time.time()
                 loop = asyncio.new_event_loop()
                 asyncio.set_event_loop(loop)
 
-                # Pre-warm MCP servers (especially vector search)
-                logger.info("Pre-warming MCP servers to eliminate startup delay...")
-                loop.run_until_complete(pre_warm_mcp_servers())
-
-                pre_warm_time = time.time() - start_time
-                if pre_warm_time > 1.0:
-                    logger.info(f"MCP servers pre-warmed in {pre_warm_time:.2f}s")
-
                 # Also run gateway verification if needed
                 if not gateway_configured:
                     loop.run_until_complete(verify_mcp_gateway_on_startup())
