@@ -7,18 +7,18 @@ Specialized manager for base_agent.md with structured update capabilities.
 Enforces template structure and provides section-specific update methods.
 """
 
-import logging
 from dataclasses import dataclass, field
-from datetime import datetime
+from datetime import datetime, timezone
 from enum import Enum
 from pathlib import Path
 from typing import Any, Dict, List, Optional
 
 from claude_mpm.agents.base_agent_loader import clear_base_agent_cache
+from claude_mpm.core.logging_utils import get_logger
 from claude_mpm.services.memory.cache.shared_prompt_cache import SharedPromptCache
 from claude_mpm.services.shared import ConfigServiceBase
 
-logger = logging.getLogger(__name__)
+logger = get_logger(__name__)
 
 
 class BaseAgentSection(str, Enum):
@@ -67,7 +67,9 @@ class BaseAgentStructure:
 class BaseAgentManager(ConfigServiceBase):
     """Manages base_agent.md with structured updates and validation."""
 
-    def __init__(self, agents_dir: Optional[Path] = None, config: Optional[Dict[str, Any]] = None):
+    def __init__(
+        self, agents_dir: Optional[Path] = None, config: Optional[Dict[str, Any]] = None
+    ):
         """Initialize BaseAgentManager."""
         super().__init__("base_agent_manager", config=config)
 
@@ -75,7 +77,7 @@ class BaseAgentManager(ConfigServiceBase):
         self.agents_dir = self.get_config_value(
             "agents_dir",
             default=agents_dir or Path(__file__).parent.parent / "agents",
-            config_type=Path
+            config_type=Path,
         )
         self.base_agent_path = self.agents_dir / "BASE_AGENT_TEMPLATE.md"
         self.cache = SharedPromptCache.get_instance()
@@ -347,9 +349,7 @@ class BaseAgentManager(ConfigServiceBase):
         items = []
         for line in content.split("\n"):
             line = line.strip()
-            if line.startswith("- "):
-                items.append(line[2:].strip())
-            elif line.startswith("* "):
+            if line.startswith(("- ", "* ")):
                 items.append(line[2:].strip())
             elif line.startswith("**") and line.endswith("**"):
                 # Skip bold headers
@@ -358,7 +358,7 @@ class BaseAgentManager(ConfigServiceBase):
 
     def _create_backup(self) -> Path:
         """Create a timestamped backup of base_agent.md."""
-        timestamp = datetime.now().strftime("%Y%m%d_%H%M%S")
+        timestamp = datetime.now(timezone.utc).strftime("%Y%m%d_%H%M%S")
         backup_path = self.base_agent_path.parent / f"base_agent_{timestamp}.backup"
 
         if self.base_agent_path.exists():
