@@ -13,14 +13,17 @@ that was previously embedded in FrameworkLoader. It manages:
 The service consolidates path management logic while maintaining backward compatibility.
 """
 
-import logging
 import subprocess
 from enum import Enum
 from pathlib import Path
 from typing import Dict, Optional, Tuple
 
+from claude_mpm.core.logging_utils import get_logger
+
 from .service_interfaces import ICacheManager, IPathResolver
 
+logger = get_logger(__name__)
+
 
 class DeploymentContext(Enum):
     """Deployment context enumeration."""
@@ -48,7 +51,7 @@ class PathResolver(IPathResolver):
         Args:
             cache_manager: Optional cache manager for caching resolved paths
         """
-        self.logger = logging.getLogger(__name__)
+        self.logger = get_logger("path_resolver")
         self.cache_manager = cache_manager
         self._framework_path: Optional[Path] = None
         self._deployment_context: Optional[DeploymentContext] = None
@@ -163,7 +166,7 @@ class PathResolver(IPathResolver):
         self.logger.debug(f"No project root found from {start_path}")
         return None
 
-    def detect_framework_path(self) -> Optional[Path]:
+    def detect_framework_path(self) -> Optional[Path]:  # noqa: PLR0911
         """
         Auto-detect claude-mpm framework using unified path management.
 
