@@ -20,6 +20,7 @@ import json
 import os
 import signal
 import subprocess
+import sys
 import threading
 import time
 from pathlib import Path
@@ -484,6 +485,21 @@ async def auto_initialize_vector_search():
 
         if vector_config.exists():
             logger.debug(f"Vector search already initialized for {current_dir}")
+
+            # Ensure .mcp-vector-search is in gitignore even if already initialized
+            try:
+                from ....services.project.project_organizer import ProjectOrganizer
+
+                if (current_dir / ".claude-mpm").exists() or (
+                    current_dir / ".git"
+                ).exists():
+                    organizer = ProjectOrganizer(current_dir)
+                    organizer.update_gitignore(
+                        additional_patterns=[".mcp-vector-search/"]
+                    )
+                    logger.debug("Ensured .mcp-vector-search is in gitignore")
+            except Exception as e:
+                logger.debug(f"Could not update gitignore for .mcp-vector-search: {e}")
             # Check if index needs rebuilding (corrupted database)
             chroma_db = current_dir / ".mcp-vector-search/chroma.sqlite3"
             if chroma_db.exists():
@@ -518,6 +534,23 @@ async def auto_initialize_vector_search():
         if proc.returncode == 0:
             logger.info("✅ Vector search initialization completed")
 
+            # Ensure .mcp-vector-search is in gitignore
+            try:
+                from ....services.project.project_organizer import ProjectOrganizer
+
+                # Check if we're in a git repository (parent of .claude-mpm)
+                if (current_dir / ".claude-mpm").exists() or (
+                    current_dir / ".git"
+                ).exists():
+                    organizer = ProjectOrganizer(current_dir)
+                    organizer.update_gitignore(
+                        additional_patterns=[".mcp-vector-search/"]
+                    )
+                    logger.debug("Ensured .mcp-vector-search is in gitignore")
+            except Exception as e:
+                logger.debug(f"Could not update gitignore for .mcp-vector-search: {e}")
+                # Non-critical, don't fail initialization
+
             # Start background indexing (non-blocking)
             def background_index():
                 try:
@@ -659,6 +692,12 @@ async def auto_initialize_kuzu_memory():
                 logger.debug("kuzu-memory command not found after installation")
                 return
 
+        # Check for kuzu-memory updates (non-blocking)
+        try:
+            await _check_kuzu_memory_updates(kuzu_memory_cmd)
+        except Exception as e:
+            logger.debug(f"Update check failed (non-critical): {e}")
+
         # Initialize kuzu-memory database in current project
         current_dir = Path.cwd()
         kuzu_memories_dir = current_dir / "kuzu-memories"
@@ -668,6 +707,19 @@ async def auto_initialize_kuzu_memory():
             logger.debug(
                 f"Kuzu-memory database already initialized at {kuzu_memories_dir}"
             )
+
+            # Ensure kuzu-memories is in gitignore even if already initialized
+            try:
+                from ....services.project.project_organizer import ProjectOrganizer
+
+                if (current_dir / ".claude-mpm").exists() or (
+                    current_dir / ".git"
+                ).exists():
+                    organizer = ProjectOrganizer(current_dir)
+                    organizer.update_gitignore(additional_patterns=["kuzu-memories/"])
+                    logger.debug("Ensured kuzu-memories is in gitignore")
+            except Exception as e:
+                logger.debug(f"Could not update gitignore for kuzu-memories: {e}")
         else:
             logger.info(
                 f"🎯 Initializing kuzu-memory database for project: {current_dir}"
@@ -687,6 +739,22 @@ async def auto_initialize_kuzu_memory():
 
             if proc.returncode == 0:
                 logger.info("✅ Kuzu-memory database initialized successfully")
+
+                # Ensure kuzu-memories is in gitignore
+                try:
+                    from ....services.project.project_organizer import ProjectOrganizer
+
+                    if (current_dir / ".claude-mpm").exists() or (
+                        current_dir / ".git"
+                    ).exists():
+                        organizer = ProjectOrganizer(current_dir)
+                        organizer.update_gitignore(
+                            additional_patterns=["kuzu-memories/"]
+                        )
+                        logger.debug("Ensured kuzu-memories is in gitignore")
+                except Exception as e:
+                    logger.debug(f"Could not update gitignore for kuzu-memories: {e}")
+                    # Non-critical, don't fail initialization
             else:
                 logger.warning(f"⚠️ Kuzu-memory initialization failed: {proc.stderr}")
 
@@ -694,47 +762,201 @@ async def auto_initialize_kuzu_memory():
         logger.debug(f"Kuzu-memory auto-initialization error (non-critical): {e}")
 
 
+async def _check_kuzu_memory_updates(kuzu_cmd: Path) -> None:
+    """
+    Check for kuzu-memory updates and prompt user.
+
+    Args:
+        kuzu_cmd: Path to kuzu-memory command
+
+    WHY: Keep users informed about important updates that may fix bugs
+    or add features they need.
+
+    DESIGN DECISIONS:
+    - Non-blocking with timeout to prevent startup delays
+    - Respects user preferences and environment variables
+    - Only prompts in interactive TTY sessions
+    """
+    logger = get_logger("kuzu_memory_update")
+
+    # Skip if environment variable set
+    if os.environ.get("CLAUDE_MPM_SKIP_UPDATE_CHECK"):
+        return
+
+    # Skip if not TTY (can't prompt)
+    if not sys.stdin.isatty():
+        return
+
+    # Import update utilities
+    from ..utils.package_version_checker import PackageVersionChecker
+    from ..utils.update_preferences import UpdatePreferences
+
+    # Check if updates are enabled for this package
+    if not UpdatePreferences.should_check_package("kuzu-memory"):
+        return
+
+    try:
+        # Get current version from pipx
+        result = subprocess.run(
+            ["pipx", "list", "--json"],
+            capture_output=True,
+            text=True,
+            timeout=5,
+            check=False,
+        )
+
+        if result.returncode == 0:
+            pipx_data = json.loads(result.stdout)
+            venvs = pipx_data.get("venvs", {})
+            kuzu_info = venvs.get("kuzu-memory", {})
+            metadata = kuzu_info.get("metadata", {})
+            current_version = metadata.get("main_package", {}).get(
+                "package_version", "unknown"
+            )
+
+            if current_version != "unknown":
+                # Check for updates
+                checker = PackageVersionChecker()
+                update_info = await checker.check_for_update(
+                    "kuzu-memory", current_version
+                )
+
+                if update_info and update_info.get("update_available"):
+                    latest_version = update_info["latest"]
+
+                    # Check if user wants to skip this version
+                    if UpdatePreferences.should_skip_version(
+                        "kuzu-memory", latest_version
+                    ):
+                        logger.debug(
+                            f"Skipping kuzu-memory update to {latest_version} per user preference"
+                        )
+                        return
+
+                    # Prompt for update
+                    _prompt_kuzu_update(update_info["current"], latest_version)
+
+    except Exception as e:
+        logger.debug(f"Update check error: {e}")
+
+
+def _prompt_kuzu_update(current: str, latest: str) -> None:
+    """
+    Prompt user to update kuzu-memory.
+
+    Args:
+        current: Current installed version
+        latest: Latest available version
+    """
+    from ...cli.shared.error_handling import confirm_operation
+    from ..utils.update_preferences import UpdatePreferences
+
+    logger = get_logger("kuzu_memory_update")
+
+    message = (
+        f"\n🔄 A new version of kuzu-memory is available!\n"
+        f"   Current: v{current}\n"
+        f"   Latest:  v{latest}\n\n"
+        f"   This update may include bug fixes and performance improvements.\n"
+        f"   Update now?"
+    )
+
+    # Check if running in a non-interactive context
+    try:
+        if confirm_operation(message):
+            print("🚀 Updating kuzu-memory...")
+            try:
+                result = subprocess.run(
+                    ["pipx", "upgrade", "kuzu-memory"],
+                    capture_output=True,
+                    text=True,
+                    timeout=30,
+                    check=False,
+                )
+                if result.returncode == 0:
+                    print("✅ Successfully updated kuzu-memory!")
+                    logger.info(f"Updated kuzu-memory from {current} to {latest}")
+                else:
+                    print(f"⚠️ Update failed: {result.stderr}")
+                    logger.warning(f"kuzu-memory update failed: {result.stderr}")
+            except subprocess.TimeoutExpired:
+                print("⚠️ Update timed out. Please try again later.")
+                logger.warning("kuzu-memory update timed out")
+            except Exception as e:
+                print(f"⚠️ Update failed: {e}")
+                logger.warning(f"kuzu-memory update error: {e}")
+        else:
+            # User declined update
+            print("\n  To skip this version permanently, run:")
+            print(f"    claude-mpm config set-skip-version kuzu-memory {latest}")
+            print("  To disable update checks for kuzu-memory:")
+            print("    claude-mpm config disable-update-checks kuzu-memory")
+
+            # Ask if user wants to skip this version
+            if confirm_operation("\n  Skip this version in future checks?"):
+                UpdatePreferences.set_skip_version("kuzu-memory", latest)
+                print(f"  Version {latest} will be skipped in future checks.")
+    except (KeyboardInterrupt, EOFError):
+        # User interrupted or input not available
+        pass
+
+
 async def pre_warm_mcp_servers():
-    """Pre-warm MCP servers from configuration."""
-    # Auto-initialize vector search for current project
-    await auto_initialize_vector_search()
+    """
+    Pre-warm MCP servers from configuration.
 
-    # Auto-initialize kuzu-memory for persistent knowledge
-    await auto_initialize_kuzu_memory()
+    DISABLED: This function is currently disabled to avoid conflicts with
+    Claude Code's native MCP server management. When enabled, this can
+    cause issues with MCP server initialization and stderr/stdout handling.
 
-    pool = get_process_pool()
+    TODO: Re-enable after ensuring compatibility with Claude Code's MCP handling.
+    """
+    logger = get_logger("MCPProcessPool")
+    logger.debug("MCP server pre-warming is currently disabled")
 
-    # Load MCP configurations
-    configs = {}
+    # COMMENTED OUT: Auto-initialization that can interfere with Claude Code
+    # # Auto-initialize vector search for current project
+    # await auto_initialize_vector_search()
+    #
+    # # Auto-initialize kuzu-memory for persistent knowledge
+    # await auto_initialize_kuzu_memory()
+    #
+    # pool = get_process_pool()
+    #
+    # # Load MCP configurations
+    # configs = {}
+    #
+    # # Check .claude.json for MCP server configs
+    # claude_config_path = Path.home() / ".claude.json"
+    # if not claude_config_path.exists():
+    #     # Try project-local config
+    #     claude_config_path = Path.cwd() / ".claude.json"
+    #
+    # if claude_config_path.exists():
+    #     try:
+    #         with open(claude_config_path) as f:
+    #             config_data = json.load(f)
+    #             mcp_servers = config_data.get("mcpServers", {})
+    #             configs.update(mcp_servers)
+    #     except Exception as e:
+    #         get_logger("MCPProcessPool").warning(f"Failed to load Claude config: {e}")
+    #
+    # # Check .mcp.json for additional configs
+    # mcp_config_path = Path.cwd() / ".mcp.json"
+    # if mcp_config_path.exists():
+    #     try:
+    #         with open(mcp_config_path) as f:
+    #             config_data = json.load(f)
+    #             mcp_servers = config_data.get("mcpServers", {})
+    #             configs.update(mcp_servers)
+    #     except Exception as e:
+    #         get_logger("MCPProcessPool").warning(f"Failed to load MCP config: {e}")
+    #
+    # if configs:
+    #     await pool.pre_warm_servers(configs)
+    #     await pool.start_health_monitoring()
+    #
+    # return pool
 
-    # Check .claude.json for MCP server configs
-    claude_config_path = Path.home() / ".claude.json"
-    if not claude_config_path.exists():
-        # Try project-local config
-        claude_config_path = Path.cwd() / ".claude.json"
-
-    if claude_config_path.exists():
-        try:
-            with open(claude_config_path) as f:
-                config_data = json.load(f)
-                mcp_servers = config_data.get("mcpServers", {})
-                configs.update(mcp_servers)
-        except Exception as e:
-            get_logger("MCPProcessPool").warning(f"Failed to load Claude config: {e}")
-
-    # Check .mcp.json for additional configs
-    mcp_config_path = Path.cwd() / ".mcp.json"
-    if mcp_config_path.exists():
-        try:
-            with open(mcp_config_path) as f:
-                config_data = json.load(f)
-                mcp_servers = config_data.get("mcpServers", {})
-                configs.update(mcp_servers)
-        except Exception as e:
-            get_logger("MCPProcessPool").warning(f"Failed to load MCP config: {e}")
-
-    if configs:
-        await pool.pre_warm_servers(configs)
-        await pool.start_health_monitoring()
-
-    return pool
+    # Return a basic pool instance without pre-warming
+    return get_process_pool()
