@@ -107,13 +107,16 @@ try:
 except ImportError:
     DocumentSummarizerTool = None
 
+# Ticket tools removed - using mcp-ticketer instead
+UnifiedTicketTool = None
+
 try:
-    from claude_mpm.services.mcp_gateway.tools.unified_ticket_tool import (
-        UnifiedTicketTool,
+    from claude_mpm.services.mcp_gateway.tools.external_mcp_services import (
+        ExternalMCPServiceManager,
     )
 except ImportError:
-    # Unified ticket tool is optional
-    UnifiedTicketTool = None
+    # External MCP services are optional
+    ExternalMCPServiceManager = None
 
 # Manager module removed - using simplified architecture
 
@@ -148,6 +151,7 @@ class MCPGatewayOrchestrator:
         self.registry: Optional[ToolRegistry] = None
         self.communication: Optional[StdioHandler] = None
         self.configuration: Optional[MCPConfiguration] = None
+        self.external_services: Optional[ExternalMCPServiceManager] = None
 
         # Shutdown handling
         self._shutdown_event = asyncio.Event()
@@ -199,6 +203,42 @@ class MCPGatewayOrchestrator:
                     self.logger.warning(f"Failed to register some tools: {e}")
                     # Continue - server can run with partial tools
 
+            # Initialize external MCP services if available
+            if ExternalMCPServiceManager is not None:
+                try:
+                    self.logger.info("Initializing external MCP services...")
+                    self.external_services = ExternalMCPServiceManager()
+                    external_services = (
+                        await self.external_services.initialize_services()
+                    )
+
+                    if external_services and self.registry:
+                        for service in external_services:
+                            try:
+                                if self.registry.register_tool(
+                                    service, category="external"
+                                ):
+                                    self.logger.info(
+                                        f"Registered external service: {service.service_name}"
+                                    )
+                                else:
+                                    self.logger.warning(
+                                        f"Failed to register external service: {service.service_name}"
+                                    )
+                            except Exception as e:
+                                self.logger.warning(
+                                    f"Error registering {service.service_name}: {e}"
+                                )
+
+                    self.logger.info(
+                        f"Initialized {len(external_services)} external MCP services"
+                    )
+                except Exception as e:
+                    self.logger.warning(
+                        f"Failed to initialize external MCP services: {e}"
+                    )
+                    self.external_services = None
+
             # Initialize communication handler with fallback
             try:
                 self.communication = StdioHandler()
@@ -271,12 +311,7 @@ class MCPGatewayOrchestrator:
             except Exception as e:
                 self.logger.warning(f"Could not load document summarizer: {e}")
 
-        # Optional: Unified ticket management tool
-        if UnifiedTicketTool is not None:
-            try:
-                tools.append(UnifiedTicketTool())
-            except Exception as e:
-                self.logger.warning(f"Could not load unified ticket tool: {e}")
+        # Ticket tools removed - mcp-ticketer provides ticket functionality
 
         if not tools:
             self.logger.warning("No tools available to register")
@@ -371,6 +406,13 @@ class MCPGatewayOrchestrator:
                 except Exception as e:
                     self.logger.warning(f"Error during communication shutdown: {e}")
 
+            # Shutdown external services
+            if self.external_services:
+                try:
+                    await self.external_services.shutdown()
+                except Exception as e:
+                    self.logger.warning(f"Error during external services shutdown: {e}")
+
             self.logger.info("MCP Gateway shutdown complete")
 
         except Exception as e:
