@@ -12,13 +12,25 @@ from .base_adapter import (
     SystemInfoToolAdapter,
 )
 from .document_summarizer import DocumentSummarizerTool
-from .unified_ticket_tool import UnifiedTicketTool
+from .kuzu_memory_service import (
+    KuzuMemoryService,
+    get_context,
+    recall_memories,
+    search_memories,
+    store_memory,
+)
+
+# Ticket tools removed - using mcp-ticketer instead
 
 __all__ = [
     "BaseToolAdapter",
-    "EchoToolAdapter",
     "CalculatorToolAdapter",
-    "SystemInfoToolAdapter",
     "DocumentSummarizerTool",
-    "UnifiedTicketTool",
+    "EchoToolAdapter",
+    "KuzuMemoryService",
+    "SystemInfoToolAdapter",
+    "get_context",
+    "recall_memories",
+    "search_memories",
+    "store_memory",
 ]
