@@ -16,6 +16,7 @@ Author: Claude MPM Development Team
 Created: 2025-01-26
 """
 
+import contextlib
 import difflib
 import gzip
 import hashlib
@@ -173,7 +174,7 @@ Generated by Claude MPM Archive Manager
         # Compress old archives
         cutoff_compress = datetime.now() - timedelta(days=self.COMPRESS_AFTER_DAYS)
         for archive in archives:
-            if not archive.suffix == ".gz":
+            if archive.suffix != ".gz":
                 mtime = datetime.fromtimestamp(archive.stat().st_mtime)
                 if mtime < cutoff_compress:
                     self._compress_archive(archive)
@@ -247,7 +248,7 @@ Generated by Claude MPM Archive Manager
             archive_files = [
                 f
                 for f in self.archive_path.glob("*")
-                if not f.name.endswith(".meta.json") and not f.name == "README.md"
+                if not f.name.endswith(".meta.json") and f.name != "README.md"
             ]
 
         for archive_file in archive_files:
@@ -265,10 +266,8 @@ Generated by Claude MPM Archive Manager
             if include_metadata:
                 meta_path = self.archive_path / f"{archive_file.name}.meta.json"
                 if meta_path.exists():
-                    try:
+                    with contextlib.suppress(Exception):
                         info["metadata"] = json.loads(meta_path.read_text())
-                    except Exception:
-                        pass
 
             archives.append(info)
 
@@ -452,7 +451,7 @@ Generated by Claude MPM Archive Manager
 
         try:
             result = subprocess.run(
-                ["git"] + args,
+                ["git", *args],
                 cwd=self.project_path,
                 capture_output=True,
                 text=True,
@@ -528,7 +527,7 @@ Generated by Claude MPM Archive Manager
         }
 
         # Review each key documentation file
-        for doc_file, description in self.key_docs.items():
+        for doc_file, _description in self.key_docs.items():
             file_path = self.project_path / doc_file
             if file_path.exists():
                 file_report = self._review_single_doc(file_path, check_git)
@@ -956,14 +955,12 @@ Generated by Claude MPM Archive Manager
         )
 
         # Update explicit version mentions
-        content = re.sub(
+        return re.sub(
             r"(?:Version|version|v)\s*\d+\.\d+\.\d+",
             f"v{new_version}",
             content,
         )
 
-        return content
-
     def display_review_summary(self, review: Dict) -> None:
         """Display a formatted summary of the documentation review."""
         console.print("\n[bold cyan]📚 Documentation Review Summary[/bold cyan]\n")
