@@ -54,6 +54,10 @@ class ProjectOrganizer:
         ".claude-mpm/cache/",
         ".claude-mpm/logs/",
         ".claude/cache/",
+        # MCP service directories for local data
+        ".mcp-vector-search/",
+        ".kuzu-memory/",
+        "kuzu-memories/",  # kuzu-memory database directory
         # Python artifacts
         "__pycache__/",
         "*.py[cod]",
@@ -444,11 +448,11 @@ This directory is used for {description.lower()}.
             existing_patterns = set()
             if self.gitignore_path.exists():
                 content = self.gitignore_path.read_text()
-                existing_patterns = set(
+                existing_patterns = {
                     line.strip()
                     for line in content.splitlines()
                     if line.strip() and not line.startswith("#")
-                )
+                }
             else:
                 content = ""
 
@@ -973,16 +977,12 @@ This directory is used for {description.lower()}.
         root_files = list(self.project_path.glob("*"))
         misplaced_count = 0
         for file in root_files:
-            if file.is_file():
-                if (
-                    ("test" in file.name.lower() and file.suffix == ".py")
-                    or (
-                        file.suffix in [".sh", ".bash"]
-                        and file.name not in ["Makefile"]
-                    )
-                    or file.suffix in [".log", ".tmp", ".cache"]
-                ):
-                    misplaced_count += 1
+            if file.is_file() and (
+                ("test" in file.name.lower() and file.suffix == ".py")
+                or (file.suffix in [".sh", ".bash"] and file.name not in ["Makefile"])
+                or file.suffix in [".log", ".tmp", ".cache"]
+            ):
+                misplaced_count += 1
 
         if misplaced_count > 0:
             validation["warnings"].append(
